#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/delete_busy_hour.sh
#
SCRIPTNAME=`basename $0`
DB_CONNECT=`crypt_util.ksh -g ${DBUSER} -c`

show_title()
{
   echo
   echo Prospect User Busy Hour Document Delete Utility.
   echo ----------------------------------------------------------------------
   echo @(#) delete_busy_hour.sh
   echo @(#) 
   echo Copyright 2010 IBM Corp.
   echo ----------------------------------------------------------------------
   echo
}

usage() {
   show_title
   echo 
   echo "USAGE: "
   echo "${SCRIPTNAME} [-entityname <entityname> -bhname <bhname>] | [-file <filename>] | -output <output_log> | [-force] | [-h <usage>] "
   echo
   echo "-h          : Displays the help usage section. "
   echo "-entityname : (Optional) Entity name where the busy hour is defined. Cannot be used with -file." 
   echo "-bhname     : (Optional) Document name. Cannot be used with -file. "
   echo "-file       : (Optional) Name of the input file with records to be processed. "
   echo "                         The file is a tab delimited file (one record per line). For e.g. "
   echo "                         BTS	Busy_hour1 "
   echo "-output     : (Mandatory) User must enter a log file name. "
   echo "-force      : (Optional) When user enters -force user will not be prompted to confirm the Delete. "
   echo
   echo "Example: Delete Single Busy Hour Document "
   echo "${SCRIPTNAME} -entityname BTS -bhname Busy_hour1 -output /tmp/delete_busy_hour.log -force "
   echo
   echo "Example: Delete Multiple Busy Hour Document in input file "
   echo "${SCRIPTNAME} -file busy_hour.lst -output /tmp/delete_busy_hour.log "
   echo
   exit 2
}

pv_entityname=''
pv_bhname=''
pv_file=''
pv_output=''
pv_force='0'
scriptStatus='0'
scriptError='0'

#Display usage if no arguments passed
if [ $# -eq 0 ]
then
   usage
fi

#Parse arguments
while [ $# -gt 0 ]
do
    case $1 in
		  -entityname)
			  shift
			  pv_entityname=$1
			  ;;
		  -bhname)
			  shift
			  pv_bhname=$1
			  ;;
		  -file)
			 shift
			 pv_file=$1
			 ;;
		  -output)
			 shift
			 pv_output=$1
			 ;;
		  -force)
			 pv_force=1
			 ;;
		  -h|-help)
			 usage
			 ;;
		  *)
			 echo "${SCRIPTNAME}: Invalid parameter $1 "
			 usage
	esac
     
     if [ $# -gt 0 ]
     then
          shift
     fi
done

checkforce()
{
if [ "$pv_force" != "1" ]
then 
   echo ""
   echo "WARNING!: Delete Busy Hour Document(s)"
   echo "Are you sure want to Delete [y/n] : \c "  
   read answer 
   
   if [ -z "$answer" ]
   then
      echo "Terminating. No busy hour will be deleted"
      exit 1
   fi
   
   if [ "$answer" != 'y' ] && [ "$answer" != 'Y' ] 
   then
      echo "Terminating. No busy hour will be deleted"
      exit 1
   fi
   
 fi     
}

function log_into_db
{
lv_component=$1
lv_log_msg=$2
sqlplus -s ${DB_CONNECT} <<SQLPLUS
  WHENEVER SQLERROR EXIT FAILURE
  set pagesize 800
  set linesize 150
  set verify off
  set heading off
  set showmode off
  set feedback off
  set serveroutput on size unlimited
  DECLARE
  BEGIN
     wm_log.log_message('$lv_component', '$lv_log_msg');
  EXCEPTION
      WHEN OTHERS THEN
           NULL;
  END;
  /
  EXIT
SQLPLUS

}

function runplsqlproc
{
sqlplus -s ${DB_CONNECT} <<SQLPLUS
	WHENEVER SQLERROR EXIT FAILURE
	set pagesize 800
	set linesize 150
	set verify off
	set heading off
	set showmode off
	set feedback off
	set serveroutput on size unlimited
	variable returnstatus number
	DECLARE

	BEGIN

		BH_Delete.delete_busy_hour($pv_entityname, $pv_bhname);
		wm_log.log_message('$SCRIPTNAME', 'Busy hour '||$pv_bhname||' Deleted');
		COMMIT;

		:returnstatus := 0;

	EXCEPTION 
	  WHEN OTHERS THEN
		   ROLLBACK;	     
		   :returnstatus := 1;
		   wm_log.log_message('$SCRIPTNAME', 'Busy hour '||$pv_bhname||' Delete FAILED');		   
		   IF (SQLCODE = -20509) THEN
			  dbms_output.put_line('ORA'||SQLCODE||' Document has dependencies Cannot Delete.' || chr(10));
		   ELSIF (SQLCODE = -20510) THEN  
			  null;
		   ELSE
			  RAISE;
		   END IF;
		   
	END;
	/
	EXIT :returnstatus
SQLPLUS

}



#Check mandotary arguments
if [[ -z "$pv_entityname" || -z "$pv_bhname" ]]
then
     if [[ -z "$pv_file" ]]
     then
          echo
	  echo "${SCRIPTNAME}: -entityname & -bhname or -file argument not passed" >&2
          usage
          exit 1
     fi
fi

#Check -file argument constraints
if [ -n "$pv_file" ]
then
     if [[ -n "$pv_entityname" && -n "$pv_bhname" ]]
     then
          echo
	  echo "${SCRIPTNAME}: -file cannot be used with -entityname or -bhname" >&2
	  usage
	  exit 1
     fi
fi

#Check Mandotary -output argument
if [ ! "$pv_output" ] 
then
     echo
     echo "${SCRIPTNAME}: Mandatory -output arguments not passed !" >&2
     usage
     exit 1
fi 

#Check dir/path is valid
DIRNAME=`dirname ${pv_output}`
if [[ ! -d ${DIRNAME} ]]
then
     echo
     echo "${SCRIPTNAME}: Invalid output path"
     exit 1
fi

#Check Log file writable
> $pv_output
if [ $? -ne 0 ]
then
	 echo
	 echo "${SCRIPTNAME}: Cannot write to $pv_output" >&2
	 exit 1
fi

#Check input file
if [[ "$pv_file" != "" ]]
then
   ###check if file exists
   if [[ ! -a "$pv_file" ]] 
   then 
     echo
     echo "${SCRIPTNAME}: ${pv_file} does not exist"
     exit 1
   fi
   ###check if file size > zero
   if [[ ! -s "$pv_file" ]] 
   then 
     echo
     echo "${SCRIPTNAME}: ${pv_file} does not contain any data"
     exit 1
   fi   
fi

#Check if -force argurment pass else prompt message before delete
checkforce

#Start spooling log file
(
echo 
echo "Delete Busy Hour Process STARTED: $(date)"
echo 
echo "Arguments passed:"
echo "-----------------"

if [[ -n "$pv_entityname" && -n "$pv_bhname" ]]
then 
     echo " Entity name - ${pv_entityname}" 
     echo " BH name - ${pv_bhname}"
fi

if [ -n "$pv_file" ]
then
     echo " Filename - ${pv_file}"
fi

echo " Output name - ${pv_output}"
echo

#---------------------------------------------------------------------------
# STARTUP
#---------------------------------------------------------------------------
#
echo "==================================================================================" 
echo "***"
echo "*** Delete Busy Hour Documents"
echo "***"
echo 
echo "Deleting..." 
echo

#---------------------------------------------------------------------------
# DELETE
#---------------------------------------------------------------------------
#
if [[ -n "$pv_file" && -e "$pv_file" ]]
then
   log_into_db $SCRIPTNAME "Start deleting busy hour"
   doc_no=0
   while read doc_file
   do
     doc_no=$((doc_no+1))
     isScriptErr=0; 
     echo "$doc_file" | awk '{print $1}' | read pv_entityname
     echo "$doc_file" | awk 'BEGIN {FS="\t";}{print $2}' | read pv_bhname

	 pv_entityname="'"$pv_entityname"'"
     pv_bhname="'"$pv_bhname"'"

	 runplsqlproc 
	 scriptStatus=$? 
	 if [ ${scriptStatus} -ne 0 ]
	 then
		scriptError=1;
	 fi
	
   done < $pv_file
   
   log_into_db $SCRIPTNAME "End deleting busy hour"
   
   if [ "$doc_no" -eq 0 ]
   then
      echo | tee -a $pv_output
      echo "${SCRIPTNAME}: File does not contain any data !" >$2 | tee -a $pv_output
      exit 1
   fi
else
     pv_entityname="'"$pv_entityname"'"
     pv_bhname="'"$pv_bhname"'"
	 
	 log_into_db $SCRIPTNAME "Start deleting busy hour"

	 runplsqlproc 
	 scriptStatus=$? 
	 if  [ ${scriptStatus} -ne 0 ]
	 then
		scriptError=1;
	 fi
	
	 log_into_db $SCRIPTNAME "End deleting busy hour"
fi

#---------------------------------------------------------------------------
# END PROCESS
#---------------------------------------------------------------------------
echo
echo "=================================================================================="
echo "Delete Process FINISHED: $(date)"
echo

if [ "$scriptError" != "0" ]
then
	echo "Script completed with ERRORS, refer log file for more information: : ${pv_output}" 
	echo ""
	exit 1
else	
    echo "Script Completed Successfully "
	echo ""
	exit 0
fi 
) | tee -a $pv_output	

